==> kubernetes-model-1.0.50-sources.jar: io/fabric8/openshift/api/model/DoneableOAuthAuthorizeToken.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.model.HasMetadata;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;

public class DoneableOAuthAuthorizeToken extends OAuthAuthorizeTokenFluentImpl<DoneableOAuthAuthorizeToken> implements Doneable<OAuthAuthorizeToken>,OAuthAuthorizeTokenFluent<DoneableOAuthAuthorizeToken>{


    private final OAuthAuthorizeTokenBuilder builder;    private final Function<OAuthAuthorizeToken, OAuthAuthorizeToken> function;
    public DoneableOAuthAuthorizeToken ( Function<OAuthAuthorizeToken, OAuthAuthorizeToken> function){
    this.builder=new OAuthAuthorizeTokenBuilder(this);this.function=function;
}
    public DoneableOAuthAuthorizeToken ( OAuthAuthorizeToken item,  Function<OAuthAuthorizeToken, OAuthAuthorizeToken> function){
    this.builder=new OAuthAuthorizeTokenBuilder(this);this.function=function;
}
    public DoneableOAuthAuthorizeToken ( OAuthAuthorizeToken item){
    this.builder=new OAuthAuthorizeTokenBuilder(this, item);this.function=new Function<OAuthAuthorizeToken, OAuthAuthorizeToken>() {
    public OAuthAuthorizeToken apply(OAuthAuthorizeToken item) {
        return item;
    }
}
;
}

    public OAuthAuthorizeToken done(){
     return function.apply(builder.build());
}


}

==> kubernetes-model-1.0.51-sources.jar: io/fabric8/openshift/api/model/DoneableOAuthAuthorizeToken.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class DoneableOAuthAuthorizeToken extends OAuthAuthorizeTokenFluentImpl<DoneableOAuthAuthorizeToken> implements Doneable<OAuthAuthorizeToken>, OAuthAuthorizeTokenFluent<DoneableOAuthAuthorizeToken>{


    private final OAuthAuthorizeTokenBuilder builder;    private final Function<OAuthAuthorizeToken, OAuthAuthorizeToken> function;
    public DoneableOAuthAuthorizeToken ( Function<OAuthAuthorizeToken, OAuthAuthorizeToken> function){
    this.builder=new OAuthAuthorizeTokenBuilder(this);this.function=function;
}
    public DoneableOAuthAuthorizeToken ( OAuthAuthorizeToken item,  Function<OAuthAuthorizeToken, OAuthAuthorizeToken> function){
    this.builder=new OAuthAuthorizeTokenBuilder(this, item);this.function=function;
}
    public DoneableOAuthAuthorizeToken ( OAuthAuthorizeToken item){
    this.builder=new OAuthAuthorizeTokenBuilder(this, item);this.function=new Function<OAuthAuthorizeToken, OAuthAuthorizeToken>() {
    public OAuthAuthorizeToken apply(OAuthAuthorizeToken item) {
        return item;
    }
}
;
}

    public OAuthAuthorizeToken done(){
     return function.apply(builder.build());
}


}
